@@ -5,6 +5,7 @@ import os
 from .criterion import CriterionAggregatorCallback
 from .cutmix_callback import CutmixCallback
 from .knn import KNNMetricCallback
+from .optimizer import SaveModelGradsCallback
 from .telegram_logger import TelegramLogger
 
 logger = logging.getLogger(__name__)
@@ -13,11 +14,11 @@ try:
     import alchemy
     from .alchemy import AlchemyLogger
 except ImportError as ex:
-    logger.warning(
-        "alchemy not available, to install alchemy, "
-        "run `pip install alchemy-catalyst`."
-    )
     if os.environ.get("USE_ALCHEMY", "0") == "1":
+        logger.warning(
+            "alchemy not available, to install alchemy, "
+            "run `pip install alchemy`."
+        )
         raise ex
 
 try:
