@@ -1,20 +1,24 @@
-from typing import List  # isort:skip
+from typing import List
 from abc import ABC, abstractmethod
 
-import torch.nn as nn
+from torch import nn
 
 
 def _take(elements, indexes):
-    return list([elements[i] for i in indexes])
+    return [elements[i] for i in indexes]
 
 
 class EncoderSpec(ABC, nn.Module):
+    """@TODO: Docs. Contribution is welcome."""
+
     @property
     @abstractmethod
     def out_channels(self) -> List[int]:
+        """Number of channels produced by the block."""
         pass
 
     @property
     @abstractmethod
     def out_strides(self) -> List[int]:
+        """@TODO: Docs. Contribution is welcome."""
         pass
