@@ -1,4 +1,4 @@
-from typing import List, Optional  # isort:skip
+from typing import List, Optional
 from abc import ABC
 
 from torch.optim.lr_scheduler import _LRScheduler
@@ -7,12 +7,10 @@ from catalyst.utils import set_optimizer_momentum
 
 
 class BaseScheduler(_LRScheduler, ABC):
-    """
-    Base class for all schedulers with momentum update
-    """
+    """Base class for all schedulers with momentum update."""
+
     def get_momentum(self) -> List[float]:
-        """
-        Function that returns the new momentum for optimizer
+        """Function that returns the new momentum for optimizer.
 
         Returns:
             List[float]: calculated momentum for every param groups
@@ -20,11 +18,10 @@ class BaseScheduler(_LRScheduler, ABC):
         raise NotImplementedError
 
     def step(self, epoch: Optional[int] = None) -> None:
-        """
-        Make one scheduler step
+        """Make one scheduler step.
 
         Args:
-            epoch (int, optional): current epoch's num
+            epoch (int, optional): current epoch num
         """
         super().step(epoch)
         momentums = self.get_momentum()
@@ -33,4 +30,4 @@ class BaseScheduler(_LRScheduler, ABC):
 
 
 class BatchScheduler(BaseScheduler, ABC):
-    pass
+    """@TODO: Docs. Contribution is welcome."""
