@@ -25,7 +25,7 @@ class _MetricCallback(ABC, Callback):
         """@TODO: Docs. Contribution is welcome."""
         super().__init__(order=CallbackOrder.Metric, node=CallbackNode.All)
         self.prefix = prefix
-        # self.metric_fn = partial(metric_fn, **metric_params)
+        # self.metric_fn = partial(metric_fn, **metrics_kwargs)
         self.input_key = input_key
         self.output_key = output_key
         self.multiplier = multiplier
@@ -66,15 +66,15 @@ class _MetricCallback(ABC, Callback):
         pass
 
     def _compute_metric_value(self, state: State):
-        output = self._get_output(state.batch_out, self.output_key)
-        input = self._get_input(state.batch_in, self.input_key)
+        output = self._get_output(state.output, self.output_key)
+        input = self._get_input(state.input, self.input_key)
 
         metric = self.metric_fn(output, input, **self.metrics_kwargs)
         return metric
 
     def _compute_metric_key_value(self, state: State):
-        output = self._get_output(state.batch_out, self.output_key)
-        input = self._get_input(state.batch_in, self.input_key)
+        output = self._get_output(state.output, self.output_key)
+        input = self._get_input(state.input, self.input_key)
 
         metric = self.metric_fn(**output, **input, **self.metrics_kwargs)
         return metric
@@ -183,14 +183,14 @@ class MetricAggregationCallback(Callback):
         if mode in ("sum", "mean"):
             if metrics is not None and not isinstance(metrics, list):
                 raise ValueError(
-                    "For `sum` or `mean` mode the loss_keys must be "
+                    "For `sum` or `mean` mode the metrics must be "
                     "None or list or str (not dict)"
                 )
         elif mode in ("weighted_sum", "weighted_mean"):
             if metrics is None or not isinstance(metrics, dict):
                 raise ValueError(
                     "For `weighted_sum` or `weighted_mean` mode "
-                    "the loss_keys must be specified "
+                    "the metrics must be specified "
                     "and must be a dict"
                 )
         else:
