@@ -5,7 +5,9 @@ from .auc import AUCCallback
 from .dice import DiceCallback, MulticlassDiceMetricCallback
 from .f1_score import F1ScoreCallback
 from .iou import (
-    ClasswiseIouCallback, ClasswiseJaccardCallback, IouCallback,
-    JaccardCallback
+    ClasswiseIouCallback,
+    ClasswiseJaccardCallback,
+    IouCallback,
+    JaccardCallback,
 )
 from .ppv_tpr_f1 import PrecisionRecallF1ScoreCallback
