@@ -5,8 +5,7 @@ from packaging.version import parse, Version
 
 
 def set_global_seed(seed: int) -> None:
-    """
-    Sets random seed into PyTorch, TensorFlow, Numpy and Random.
+    """Sets random seed into PyTorch, TensorFlow, Numpy and Random.
 
     Args:
         seed: random seed
@@ -31,3 +30,6 @@ def set_global_seed(seed: int) -> None:
             tf.compat.v1.set_random_seed(seed)
     random.seed(seed)
     np.random.seed(seed)
+
+
+__all__ = ["set_global_seed"]
