@@ -3,12 +3,8 @@ from torch.utils.data import DataLoader, TensorDataset
 
 from catalyst.dl import SupervisedRunner
 
-# experiment setup
-logdir = "./logdir"
-num_epochs = 8
-
 # data
-num_samples, num_features = int(1e4), int(1e1)
+num_samples, num_features = int(32e3), int(1e1)
 X, y = torch.rand(num_samples, num_features), torch.rand(num_samples)
 dataset = TensorDataset(X, y)
 loader = DataLoader(dataset, batch_size=32, num_workers=1)
@@ -20,16 +16,22 @@ criterion = torch.nn.MSELoss()
 optimizer = torch.optim.Adam(model.parameters())
 scheduler = torch.optim.lr_scheduler.MultiStepLR(optimizer, [3, 6])
 
-# model training
 runner = SupervisedRunner()
+# model training
 runner.train(
     model=model,
     criterion=criterion,
     optimizer=optimizer,
     scheduler=scheduler,
     loaders=loaders,
-    logdir=logdir,
-    num_epochs=num_epochs,
+    logdir="./logdir",
+    num_epochs=8,
     verbose=True,
     check=True,
+    load_best_on_end=True,
 )
+# model inference
+for prediction in runner.predict_loader(loader=loader):
+    assert prediction["logits"].cpu().detach().numpy().shape == (32, 1)
+# model tracing
+traced_model = runner.trace(loader=loader)
